@@ -40,6 +40,33 @@ def post_dates_to_database(dataset: pd.DataFrame, access_token: str, verbose: bo
     return pd.DataFrame.from_records(failed_uploads)
 
 
+def post_many_dates_to_database(dataset: pd.DataFrame, access_token: str, verbose: bool = True):
+    """
+    This function posts date data to the date table of the database. The function firstly checks that the input
+    arguments are of the correct type, followed by modifying the dataset into a json information packet. The json
+    information is then passed to the endpoint, with a status code and error message printed if appropriate,
+    and verbose=True.
+
+    :param dataset: a Pandas DataFrame containing the data to upload within a given schema. (pd.DataFrame)
+    :param access_token: the access token of the user, must be an active access token. (str)
+    :param verbose: determines if status is printed. Default=True. (bool)
+    :return: N/A
+    """
+    dict_list = dataset.to_json(orient='records')
+    url = "https://www.samsonrockapis.com/date_mapping/bulk"
+    header = {'Authorization': 'Bearer ' + access_token}
+    response = requests.post(url, data=dict_list, headers=header)
+    if response.status_code in [200, 201, 202, 203, 204]:
+        if verbose:
+            print("Status Code: {}, data posted to date table.".format(response.status_code))
+    elif response.status_code in [401, 403]:
+        if verbose:
+            print("Status Code: {}, user not authenticated for endpoint.".format(response.status_code))
+    else:
+        if verbose:
+            print("Status Code: {}, {}.".format(response.status_code, response.text))
+
+
 def get_index_dates(access_token: str, verbose: bool = True):
     """
     This function collects dates data from the date table of the database. The function firstly checks that the input
